@@ -5,7 +5,7 @@ use warnings;
 
 package Net::Fritz::Action;
 # ABSTRACT: represents a TR064 action
-$Net::Fritz::Action::VERSION = 'v0.0.8';
+$Net::Fritz::Action::VERSION = 'v0.0.9';
 
 use Moo;
 
@@ -96,7 +96,7 @@ Net::Fritz::Action - represents a TR064 action
 
 =head1 VERSION
 
-version v0.0.8
+version v0.0.9
 
 =head1 SYNOPSIS
 
@@ -113,7 +113,9 @@ version v0.0.8
 This class represents a TR064 action belonging to a
 L<Net::Fritz::Service>.  An action is a rather boring object
 containing the input/output parameter names as well as the action
-name.  To call (execute) an action, use L<Net::Fritz::Service/call>.
+name.  To call (execute) an action, use
+L<Net::Fritz::Service::call|Net::Fritz::Service/call(action_name
+[I<argument_hash>])>.
 
 =head1 ATTRIBUTES (read-only)
 
@@ -126,18 +128,24 @@ L<Net::Fritz::Service/scpd> XML that describes this action.
 =head2 name
 
 The name of this action as a string.  This is used to identify the
-action in a L<Net::Fritz::Service/call>.
+action in a
+L<Net::Fritz::Service::call|Net::Fritz::Service/call(action_name
+[I<argument_hash>])>.
 
 =head2 args_in
 
 An arrayref containing the names of all input parameters for this
-action.  These parameters must be present in a L<Net::Fritz::Service/call>.
+action.  These parameters must be present in a
+L<Net::Fritz::Service::call|Net::Fritz::Service/call(action_name
+[I<argument_hash>])>.
 
 =head2 args_out
 
 An arrayref containing the names of all output parameters of this
 action.  These parameters will be present in the
-L<Net::Fritz::Data/data> response to a L<Net::Fritz::Service/call>.
+L<Net::Fritz::Data/data> response to a
+L<Net::Fritz::Service::call|Net::Fritz::Service/call(action_name
+[I<argument_hash>])>.
 
 =head2 error
 
